@@ -23,7 +23,7 @@ use Moose::Util::TypeConstraints qw/duck_type/;
 
 extends 'W3C::SOAP::Base';
 
-our $VERSION     = version->new('0.05');
+our $VERSION     = version->new('0.06');
 our $DEBUG_REQUEST_RESPONSE = $ENV{W3C_SOAP_DEBUG_CLIENT};
 
 has location => (
@@ -78,7 +78,7 @@ sub post {
     );
     $self->response($response);
 
-    return $response->content;
+    return $response->decoded_content;
 }
 
 {
@@ -106,7 +106,7 @@ W3C::SOAP::Client - Client to talk SOAP to a server.
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::Client version 0.05.
+This documentation refers to W3C::SOAP::Client version 0.06.
 
 =head1 SYNOPSIS
 
