@@ -19,7 +19,7 @@ use TryCatch;
 
 extends 'W3C::SOAP::Client';
 
-our $VERSION     = version->new('0.05');
+our $VERSION     = version->new('0.06');
 
 has header => (
     is        => 'rw',
@@ -116,7 +116,7 @@ sub send {
         $content = $self->post($action, $xml);
     }
     catch ($e) {
-        $self->log->error("$action RESPONSE \n" . $self->response->content) if $self->has_log;
+        $self->log->error("$action RESPONSE \n" . $self->response->decoded_content) if $self->has_log;
 
         W3C::SOAP::Exception::HTTP->throw(
             faultcode => $self->response->code,
@@ -188,7 +188,7 @@ W3C::SOAP::WSDL - A SOAP WSDL Client object
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::WSDL version 0.05.
+This documentation refers to W3C::SOAP::WSDL version 0.06.
 
 
 =head1 SYNOPSIS
