@@ -28,8 +28,14 @@ use W3C::SOAP::Utils qw/normalise_ns ns2module/;
 
 extends 'W3C::SOAP::Document';
 
-our $VERSION     = version->new('0.05');
+our $VERSION     = version->new('0.06');
 
+has element_form_default => (
+    is         => 'rw',
+    isa        => 'Str',
+    builder    => '_element_form_default',
+    lazy_build => 1,
+);
 has imports => (
     is         => 'rw',
     isa        => 'ArrayRef[W3C::SOAP::XSD::Document]',
@@ -124,6 +130,18 @@ has ns_map => (
     lazy_build => 1,
 );
 
+sub _element_form_default {
+    my ($self) = @_;
+    my @imports;
+    my @nodes = $self->xpc->findnodes('//@elementFormDefault');
+
+    if (@nodes) {
+        return $nodes[0]->value;
+    }
+
+    return 'unqualified';
+}
+
 sub _imports {
     my ($self) = @_;
     my @imports;
@@ -250,6 +268,7 @@ sub _complex_types {
     my ($self) = @_;
     my @complex_types;
     my @nodes = $self->xpc->findnodes('/*/xsd:complexType');
+    push @nodes, $self->xpc->findnodes('/*/xsd:complexContent');
 
     for my $node (@nodes) {
         # get all top level complex types
@@ -275,6 +294,9 @@ sub _complex_types {
     while ( my $element = shift @elements ) {
         # Get the elements first sub complex type (if any)
         my ($node) = $self->xpc->findnodes('xsd:complexType', $element->node);
+        if (!$node) {
+            ($node) = $self->xpc->findnodes('xsd:complexContent', $element->node);
+        }
         next unless $node;
 
         try {
@@ -417,7 +439,7 @@ W3C::SOAP::XSD::Document - Represents a XMLSchema Document
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document version 0.05.
+This documentation refers to W3C::SOAP::XSD::Document version 0.06.
 
 =head1 SYNOPSIS
 
