@@ -19,7 +19,7 @@ use W3C::SOAP::Utils qw/split_ns/;
 
 extends 'W3C::SOAP::XSD::Document::Type';
 
-our $VERSION     = version->new('0.05');
+our $VERSION     = version->new('0.06');
 
 has sequence => (
     is      => 'rw',
@@ -49,6 +49,10 @@ has extension => (
 sub _sequence {
     my ($self) = @_;
     my ($node) = $self->document->xpc->findnodes('xsd:complexContent/xsd:extension', $self->node);
+    if (!$node) {
+        ($node) = $self->document->xpc->findnodes('xsd:extension', $self->node);
+    }
+
     return $self->_get_sequence_elements($node || $self->node);
 }
 
@@ -66,13 +70,19 @@ sub _complex_content {
 
 sub _extension {
     my ($self) = @_;
+    # TODO $suffix feels like a hack, it fixes the tests but isn't really calculated to be the correct value
+    my $suffix = '';
     my @nodes = $self->document->xpc->findnodes('xsd:complexContent/xsd:extension', $self->node);
+    if (!@nodes) {
+        @nodes = $self->document->xpc->findnodes('xsd:extension', $self->node);
+        $suffix = 'Type';
+    }
 
     for my $node (@nodes) {
         my ($ns, $tag) = split_ns($node->getAttribute('base'));
         my $ns_uri = $self->document->get_ns_uri($ns, $self->node);
 
-        return $self->document->get_module_name( $ns_uri ) . "::$tag";
+        return $self->document->get_module_name( $ns_uri ) . "::$tag" . $suffix;
     }
 
     return;
@@ -117,7 +127,7 @@ W3C::SOAP::XSD::Document::ComplexType - <One-line description of module's purpos
 
 =head1 VERSION
 
-This documentation refers to W3C::SOAP::XSD::Document::ComplexType version 0.05.
+This documentation refers to W3C::SOAP::XSD::Document::ComplexType version 0.06.
 
 
 =head1 SYNOPSIS
